==> tree_disk_rings-0.5.1-py3-none-any.whl: treediskrings/analyzer.py <==
import numpy as np
import cv2
from typing import List, Tuple, Dict, Any

from .processing.ring_count import calculate_average_ring_count
from .geometry.curve import Curve
from .geometry.chain import Chain
from .processing.preprocessing import preprocessing
from .detection.canny_devernay_edge_detector import canny_deverney_edge_detector
from .detection.filter_edges import filter_edges
from .processing.sampling import sampling_edges
from .analysis.connect_chains import connect_chains
from .processing.postprocessing import postprocessing
from .config import config


def tree_ring_detection(img_in: np.ndarray) -> Tuple[
    np.ndarray,
    np.ndarray,
    np.ndarray,
    List[Curve],
    List[Chain],
    List[Chain],
    List[Chain],
    int,
]:
    """
    Delineate tree rings over pine cross-section images. Implements Algorithm 1 from the paper.

    Args:
        img_in (np.ndarray): Segmented input image. Background must be white (255,255,255).

    Returns:
        Tuple containing:
            - img_in (np.ndarray): Original input image.
            - img_pre (np.ndarray): Preprocessed image.
            - devernay_curves (np.ndarray): Devernay curves in matrix format.
            - devernay_curves_f (List[Curve]): Filtered Devernay curves.
            - devernay_curves_s (List[Chain]): Sampled Devernay curves as Chain objects.
            - devernay_curves_c (List[Chain]): Chain lists after connect stage.
            - devernay_curves_p (List[Chain]): Chain lists after postprocessing stage.
            - average_ring_count (int): Average ring count.
    """
    img_pre = preprocessing(img_in)

    devernay_edges, gradient_x_img, gradient_y_img = canny_deverney_edge_detector(
        img_pre, sigma=config.sigma, low=config.th_low, high=config.th_high
    )

    devernay_curves_f = filter_edges(
        devernay_edges, gradient_x_img, gradient_y_img, img_pre
    )

    average_ring_count = calculate_average_ring_count(devernay_curves_f, img_in)

    devernay_curves_s, l_nodes_s = sampling_edges(devernay_curves_f, img_pre)
    devernay_curves_c, l_nodes_c = connect_chains(devernay_curves_s, img_pre)
    devernay_curves_p = postprocessing(devernay_curves_c, l_nodes_c, img_pre)

    return (
        img_in,
        img_pre,
        devernay_edges,
        devernay_curves_f,
        devernay_curves_s,
        devernay_curves_c,
        devernay_curves_p,
        average_ring_count,
    )

==> tree_disk_rings-0.6.0-py3-none-any.whl: treediskrings/analyzer.py <==
import numpy as np
import cv2
from typing import List, Tuple, Dict, Any

from .geometry.curve import Curve
from .geometry.chain import Chain
from .processing.preprocessing import preprocessing
from .detection.canny_devernay_edge_detector import canny_deverney_edge_detector
from .detection.filter_edges import filter_edges
from .processing.sampling import sampling_edges
from .analysis.connect_chains import connect_chains
from .processing.postprocessing import postprocessing
from .config import config


def tree_ring_detection(img_in: np.ndarray) -> Tuple[
    np.ndarray,
    np.ndarray,
    np.ndarray,
    List[Curve],
    List[Chain],
    List[Chain],
    List[Chain],
    int,
]:
    """
    Delineate tree rings over pine cross-section images. Implements Algorithm 1 from the paper.

    Args:
        img_in (np.ndarray): Segmented input image. Background must be white (255,255,255).

    Returns:
        Tuple containing:
            - img_in (np.ndarray): Original input image.
            - img_pre (np.ndarray): Preprocessed image.
            - devernay_curves (np.ndarray): Devernay curves in matrix format.
            - devernay_curves_f (List[Curve]): Filtered Devernay curves.
            - devernay_curves_s (List[Chain]): Sampled Devernay curves as Chain objects.
            - devernay_curves_c (List[Chain]): Chain lists after connect stage.
            - devernay_curves_p (List[Chain]): Chain lists after postprocessing stage.
            - average_ring_count (int): Average ring count.
    """
    img_pre = preprocessing(img_in)

    devernay_edges, gradient_x_img, gradient_y_img = canny_deverney_edge_detector(
        img_pre, sigma=config.sigma, low=config.th_low, high=config.th_high
    )

    devernay_curves_f = filter_edges(
        devernay_edges, gradient_x_img, gradient_y_img, img_pre
    )

    devernay_curves_s, l_nodes_s, average_ring_count = sampling_edges(
        devernay_curves_f, img_pre
    )
    devernay_curves_c, l_nodes_c = connect_chains(devernay_curves_s, img_pre)
    devernay_curves_p = postprocessing(devernay_curves_c, l_nodes_c, img_pre)

    return (
        img_in,
        img_pre,
        devernay_edges,
        devernay_curves_f,
        devernay_curves_s,
        devernay_curves_c,
        devernay_curves_p,
        average_ring_count,
    )


def tree_ring_detection_age_detect(
    img_in: np.ndarray,
) -> Tuple[np.ndarray, np.ndarray, np.ndarray, List[Curve], List[Chain], int]:
    """
    Delineate tree rings over pine cross-section images. Implements Algorithm 1 from the paper.

    Args:
        img_in (np.ndarray): Segmented input image. Background must be white (255,255,255).

    Returns:
        Tuple containing:
            - img_in (np.ndarray): Original input image.
            - img_pre (np.ndarray): Preprocessed image.
            - devernay_curves (np.ndarray): Devernay curves in matrix format.
            - devernay_curves_f (List[Curve]): Filtered Devernay curves.
            - devernay_curves_s (List[Chain]): Sampled Devernay curves as Chain objects.
            - average_ring_count (int): Average ring count.

    """
    img_pre = preprocessing(img_in)

    devernay_edges, gradient_x_img, gradient_y_img = canny_deverney_edge_detector(
        img_pre, sigma=config.sigma, low=config.th_low, high=config.th_high
    )

    devernay_curves_f = filter_edges(
        devernay_edges, gradient_x_img, gradient_y_img, img_pre
    )

    devernay_curves_s, l_nodes_s, average_ring_count = sampling_edges(
        devernay_curves_f, img_pre
    )

    return (
        img_in,
        img_pre,
        devernay_edges,
        devernay_curves_f,
        devernay_curves_s,
        average_ring_count,
    )
